package MT::Plugin::StylePreview;
use strict;

use MT;
use MT::Template::Context;
use MT::Util qw(html_text_transform);
use MT::Util qw(encode_html);
use MT::Util qw(decode_html);

our $VERSION = "0.2";

@MT::Plugin::StylePreview::ISA = qw(MT::Plugin);

my $plugin = new MT::Plugin::StylePreview({
	name => 'StylePreview',
	version => $VERSION,
	description => 'Simplicity Entry Preview with Your Template &amp; CSS.',
	author_name => 'Junnama Noda',
	author_link => 'http://junnama.alfasado.net/online/',
});

MT->add_plugin($plugin);

MT->add_callback('MT::App::CMS::AppTemplateSource.preview_entry',9 ,$plugin, \&_PickUpForm);
MT->add_callback('MT::App::CMS::AppTemplateOutput.preview_entry',9 ,$plugin, \&_StylePreview);

sub _PickUpForm {
	my ($eh, $app, $tmpl_str, $param_ref, $tmpl) = @_;
	my $remove = quotemeta('<TMPL_INCLUDE NAME="header.tmpl">');
	$$tmpl_str =~ s/$remove//;
	$remove = quotemeta('<TMPL_VAR NAME=PREVIEW_BODY>');
	$$tmpl_str =~ s/$remove//;
	$remove = quotemeta('<TMPL_INCLUDE NAME="footer.tmpl">');
	$$tmpl_str =~ s/$remove//;
	$$tmpl_str .= '<br /></body>';
1;
}

sub _StylePreview {
	my ($eh, $app, $tmpl_str, $param_ref, $tmpl) = @_;
	use MT::Blog;
	use MT::Entry;
	use MT::Builder;
	use MT::Template;
	use MT::TemplateMap;
	use MT::Template::Context;
	my $query = $app->param;
	my $user = $app->user;
	my $blog = $app->blog;
	my $blog_id = $blog->id;
	my $blog_name = $blog->name;
	my $blog_url = $blog->site_url;
	my $blog_desc = $blog->description;
	my $tmap = MT::TemplateMap->load(
							{	blog_id => $blog_id,
								archive_type => 'Individual',
								is_preferred => 1
							},);
	my $template = MT::Template->load({id => $tmap->template_id});
	my $preview_tmpl = $template->text;
	my $entry = MT::Entry->new;
	$entry->blog_id($blog_id);
	$entry->author_id($user->id);
	for my $col (qw(title text text_more excerpt keywords)) {
		(my $val = $query->param($col) || '') =~  tr/\r//d;
		$entry->$col($val);
	}
	my $created_on = $query->param('created_on_manual');
	unless ($created_on) {
		$created_on = $query->param('created_on_old');
	}
	$created_on =~ s/[\-|:|\s]//g; 
	$entry->created_on($created_on);
	if ((!defined $query->param('basename')) || ($query->param('basename') eq '')) {
		$entry->basename('preview_tmporary');
	} else {
		$entry->basename($query->param('basename'));
	}
	if (defined $query->param('allow_comments')) {
		$entry->allow_comments(1);
	}
	if (defined $query->param('allow_pings')) {
		$entry->allow_pings(1);
	}
	$entry->status(2);
	$entry->convert_breaks(scalar $query->param('convert_breaks'));
	my $new_post = 1;
	if (!defined $query->param('id')) {
		$entry->save;
	} else {
		$new_post = 0;
		$entry->id($query->param('id'));
	}
	my $ctx = MT::Template::Context->new;
	$ctx->stash('entry', $entry);
	$ctx->stash('blog', $blog);
	$ctx->stash('blog_id', $blog->id);
	my $build = MT::Builder->new;
	my $tokens = $build->compile($ctx, $preview_tmpl)
		or return $app->error($app->translate(
			"Parse error: [_1]", $build->errstr));
	defined(my $html = $build->build($ctx, $tokens))
		or return $app->error($app->translate(
			"Build error: [_1]", $build->errstr));
	if($new_post == 1) {
		$entry->remove;
	}
	my $form = $$tmpl_str;
	my $end_body = '<\/body>';
	$html =~ s/$end_body/$form/;
	$$tmpl_str = $html;
1;
}

1;